import { AllHTMLAttributes, ComponentType, ReactNode } from 'react';
import type { ComponentModule } from './types';
export interface InteractionLoaderOptions {
    /**
     * Intersection observer options.\
     * https://developer.mozilla.org/en-US/docs/Web/API/IntersectionObserver/IntersectionObserver#parameters
     */
    intersectionObserverOptions?: IntersectionObserverInit;
    /**
     * Renders the component regardless of the element is visible or not.
     * This uses `React.lazy`
     */
    force?: boolean;
    /**
     * Only when using `force` this is the fallback react node that will be used in the Suspense.
     */
    fallback?: ReactNode;
    /**
     * Placeholder element props, used when the element is not visible (For setting the dimensions for example).
     */
    placeholderProps?: AllHTMLAttributes<HTMLElement>;
}
/**
 *
 * @param load   /**
 * Function that must call a dynamic import().\
 * This must return a Promise which resolves to a module with a React component (it could be default export).
 *
 * @example
 *
 * // It has default import
 * () => import('./MyComponent')
 *
 * @example
 *
 * // Directly return a module with a component
 * async () => (await import('./MyComponent')).MyComponent
 *
 * @param options {InteractionLoaderOptions} Interaction loader options.
 */
export declare function intersectionLoader<T extends {}>(load: () => Promise<ComponentModule<T>>, { intersectionObserverOptions, force, fallback, placeholderProps }?: InteractionLoaderOptions): ComponentType<T>;
//# sourceMappingURL=intersection-loader.d.ts.map